@@ -3,13 +3,13 @@ BEGIN {
   $Carp::Reply::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Carp::Reply::VERSION = '0.02';
+  $Carp::Reply::VERSION = '0.03';
 }
 use strict;
 use warnings;
 # ABSTRACT: get a repl on exceptions in your program
 
-use Reply;
+use Reply 0.13;
 use Reply::Config;
 
 
@@ -42,7 +42,7 @@ Carp::Reply - get a repl on exceptions in your program
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
